<?php

namespace Asadi\Guardian\Http\Controllers;
use Litepie\Guardian\Http\Requests\GuardianRequest;
use Litepie\Guardian\Models\Guardian;

trait GuardianWorkflow {
	
    /**
     * Workflow controller function for guardian.
     *
     * @param Model   $guardian
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(GuardianRequest $request, Guardian $guardian, $step)
    {

        try {

            $guardian->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('guardian::guardian.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/guardian/guardian/' . $guardian->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/guardian/guardian/' . $guardian->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for guardian.
     *
     * @param Model   $guardian
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Guardian $guardian, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $guardian->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('guardian::guardian.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('guardian::admin.guardian.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('guardian::admin.guardian.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('guardian::admin.guardian.message', $data)->render();

        }

    }
}