<?php

namespace Asadi\Guardian\Policies;

use App\User;
use Asadi\Guardian\Models\Guardian;

class GuardianPolicy
{

    /**
     * Determine if the given user can view the guardian.
     *
     * @param User $user
     * @param Guardian $guardian
     *
     * @return bool
     */
    public function view(User $user, Guardian $guardian)
    {
        if ($user->canDo('guardian.guardian.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $guardian->user_id;
    }

    /**
     * Determine if the given user can create a guardian.
     *
     * @param User $user
     * @param Guardian $guardian
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('guardian.guardian.create');
    }

    /**
     * Determine if the given user can update the given guardian.
     *
     * @param User $user
     * @param Guardian $guardian
     *
     * @return bool
     */
    public function update(User $user, Guardian $guardian)
    {
        if ($user->canDo('guardian.guardian.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $guardian->user_id;
    }

    /**
     * Determine if the given user can delete the given guardian.
     *
     * @param User $user
     * @param Guardian $guardian
     *
     * @return bool
     */
    public function destroy(User $user, Guardian $guardian)
    {
        if ($user->canDo('guardian.guardian.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $guardian->user_id;
    }

    /**
     * Determine if the given user can verify the given guardian.
     *
     * @param User $user
     * @param Guardian $guardian
     *
     * @return bool
     */
    public function verify(User $user, Guardian $guardian)
    {
        if ($user->canDo('guardian.guardian.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('guardian.guardian.verify') 
        && $user->is('manager')
        && $guardian->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given guardian.
     *
     * @param User $user
     * @param Guardian $guardian
     *
     * @return bool
     */
    public function approve(User $user, Guardian $guardian)
    {
        if ($user->canDo('guardian.guardian.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
