<?php

namespace Asadi\Guardian\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Guardian\Models\Guardian;

class GuardianAction
{
    /**
     * Perform the complete action.
     *
     * @param Guardian $guardian
     *
     * @return Guardian
     */
    public function complete(Guardian $guardian)
    {
        try {
            $guardian->status = 'complete';
            return $guardian->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Guardian $guardian
     *
     * @return Guardian
     */public function verify(Guardian $guardian)
    {
        try {
            $guardian->status = 'verify';
            return $guardian->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Guardian $guardian
     *
     * @return Guardian
     */public function approve(Guardian $guardian)
    {
        try {
            $guardian->status = 'approve';
            return $guardian->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Guardian $guardian
     *
     * @return Guardian
     */public function publish(Guardian $guardian)
    {
        try {
            $guardian->status = 'publish';
            return $guardian->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Guardian $guardian
     *
     * @return Guardian
     */
    public function archive(Guardian $guardian)
    {
        try {
            $guardian->status = 'archive';
            return $guardian->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Guardian $guardian
     *
     * @return Guardian
     */
    public function unpublish(Guardian $guardian)
    {
        try {
            $guardian->status = 'unpublish';
            return $guardian->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
