<?php

namespace Asadi\Guardian\Workflow;

use Asadi\Guardian\Models\Guardian;
use Validator;

class GuardianValidator
{

    /**
     * Determine if the given guardian is valid for complete status.
     *
     * @param Guardian $guardian
     *
     * @return bool / Validator
     */
    public function complete(Guardian $guardian)
    {
        return Validator::make($guardian->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given guardian is valid for verify status.
     *
     * @param Guardian $guardian
     *
     * @return bool / Validator
     */
    public function verify(Guardian $guardian)
    {
        return Validator::make($guardian->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given guardian is valid for approve status.
     *
     * @param Guardian $guardian
     *
     * @return bool / Validator
     */
    public function approve(Guardian $guardian)
    {
        return Validator::make($guardian->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given guardian is valid for publish status.
     *
     * @param Guardian $guardian
     *
     * @return bool / Validator
     */
    public function publish(Guardian $guardian)
    {
        return Validator::make($guardian->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given guardian is valid for archive status.
     *
     * @param Guardian $guardian
     *
     * @return bool / Validator
     */
    public function archive(Guardian $guardian)
    {
        return Validator::make($guardian->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given guardian is valid for unpublish status.
     *
     * @param Guardian $guardian
     *
     * @return bool / Validator
     */
    public function unpublish(Guardian $guardian)
    {
        return Validator::make($guardian->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
